@@ -49,7 +49,10 @@ func TestMain(m *testing.M) {
 
 func Test(t *testing.T) {
 	tests := map[string]kubetest.TestSuite{
-		"Basics": testBasics(suite),
+		"Basics":        testBasics(suite),
+		"TokenAudience": testTokenAudience(suite),
+		"AllowPath":     testAllowPathsRegexp(suite),
+		"IgnorePath":    testIgnorePaths(suite),
 	}
 
 	for name, tc := range tests {
